@@ -1,6 +1,6 @@
 ;;; uniline-transient.el --- Add▶ ■─UNICODE based diagrams─■ to▶ ■─text files─■ -*- coding:utf-8; lexical-binding: t; -*-
 
-;; Copyright (C) 2024-2025  Thierry Banel
+;; Copyright (C) 2024-2026  Thierry Banel
 
 ;; Author: Thierry Banel tbanelwebmin at free dot fr
 ;; Package-Requires: ((emacs "29.1"))
@@ -188,18 +188,21 @@ for later menu invocation in the same Uniline session."
     ("a" "▷▶→▹▸↔"  uniline-insert-fw-arrow  :transient t)
     ("s" "□■◆◊"    uniline-insert-fw-square :transient t)
     ("o" "·●◦Øø"   uniline-insert-fw-oshape :transient t)
-    ("x" "╳╱╲÷×±¤" uniline-insert-fw-cross  :transient t)]
+    ("x" "╳╱╲÷×±¤" uniline-insert-fw-cross  :transient t)
+    ("SPC" " ░▒▓█" uniline-insert-fw-grey   :transient t)]
    [""
     ("A" "↔▸▹→▶▷"  uniline-insert-bw-arrow  :transient t)
     ("S" "◊◆■□"    uniline-insert-bw-square :transient t)
     ("O" "øØ◦●·"   uniline-insert-bw-oshape :transient t)
-    ("X" "¤±×÷╲╱╳" uniline-insert-bw-cross  :transient t)]
+    ("X" "¤±×÷╲╱╳" uniline-insert-bw-cross  :transient t)
+    ("DEL" "█▓▒░ " uniline-insert-bw-grey   :transient t)]
    [""
-    ("-" "-" uniline--self-insert-- :transient t)
-    ("+" "+" uniline--self-insert-+ :transient t)
-    ("=" "=" self-insert-command    :transient t)
-    ("#" "#" self-insert-command    :transient t)]
-   ["Rotate & tweak"
+    ("-" "" uniline--self-insert--     :transient t)
+    ("+" "" uniline--self-insert-+     :transient t)
+    ("=" "" self-insert-command :transient t)
+    ("#" "" self-insert-command :transient t)
+    ("~" "" self-insert-command :transient t)]
+   ["Rotate,tweak"
     ("S-<up>"    "↑" uniline-rotate-up↑ :transient t)
     ("S-<right>" "→" uniline-rotate-ri→ :transient t)
     ("S-<down>"  "↓" uniline-rotate-dw↓ :transient t)
@@ -209,13 +212,13 @@ for later menu invocation in the same Uniline session."
     ("C-<right>" "→" uniline-text-direction-ri→ :transient nil)
     ("C-<down>"  "↓" uniline-text-direction-dw↓ :transient nil)
     ("C-<left>"  "←" uniline-text-direction-lf← :transient nil)]
-   ["Contour, Fill"
-    ("c" "Draw  contour" uniline-contour)
-    ("C" "Ovwrt contour" (lambda () (interactive) (uniline-contour t)))
-    ("i" "Fill area"     uniline-fill)]
+   ["Contour,fill"
+    ("c" "Draw  cnt" uniline-contour)
+    ("C" "Ovwrt cnt" (lambda () (interactive) (uniline-contour t)))
+    ("i" "Fill area" uniline-fill)]
    ["Navigation"
-    ("f"  "Choose font" uniline-transient-fonts)
-    ("C-t" "Togg hints" uniline-toggle-transient-hints-suffix)
+    ("f"  "Font"   uniline-transient-fonts)
+    ("C-t" "Hints" uniline-toggle-transient-hints-suffix)
     ("RET" "Quit" (lambda () (interactive)) :transient nil)]]
   (interactive)
   ;; the purpose of this keymap handling is to regain the basic behavior
@@ -255,7 +258,6 @@ for later menu invocation in the same Uniline session."
    ;; ("<down>"  "↓" uniline-move-rect-dw↓ :transient t)]
    ["Misc"
     ("f"        "fonts" uniline-transient-fonts)
-    ("C-_"       "undo" uniline--rect-undo :transient t)
     ("C-t" "Togg hints" uniline-toggle-transient-hints-suffix)
     ("s"         "back" uniline-transient-moverect)
     ("RET"       "exit" uniline--rect-quit)]
@@ -287,16 +289,16 @@ for later menu invocation in the same Uniline session."
     ("k" "Kill" uniline-kill-rectangle :transient nil)
     ("y" "Yank" uniline-yank-rectangle :transient t)]
    ["Brush"
-    ("-"   "╭─╯" uniline-set-brush-1     :transient t)
-    ("+"   "┏━┛" uniline-set-brush-2     :transient t)
-    ("="   "╔═╝" uniline-set-brush-3     :transient t)
-    ("#"   "▄▄▟" uniline-set-brush-block :transient t)
-    ("DEL" "DEL" uniline-set-brush-0     :transient t)]
+    ("-"   "╭─╯" uniline-set-brush-1          :transient t)
+    ("+"   "┏━┛" uniline-set-brush-2          :transient t)
+    ("="   "╔═╝" uniline-set-brush-3          :transient t)
+    ("#"   "▄▄▟" uniline-set-brush-block      :transient t)
+    ("~"   "┄┄┄" uniline-set-brush-dot-toggle :transient t)
+    ("DEL" "DEL" uniline-set-brush-0          :transient t)]
    ["Misc"
     ("s"   "Line styles" uniline-transient-alt-styles)
     ("f"   "Choose font" uniline-transient-fonts)
     ;;("C-x C-x" "Exchg point-mark" rectangle-exchange-point-and-mark :transient t)
-    ("C-_" "Undo"        uniline--rect-undo)
     ("C-t" "Togg hints"  uniline-toggle-transient-hints-suffix)
     ("RET" "Exit"        uniline--rect-quit)]
    ]
